@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.c,v 1.125 2006/01/16 16:15:37 pborelli Exp $
+ * $Id: gedit-document.c,v 1.130 2006/02/19 18:01:09 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -76,7 +76,6 @@ PROFILE (static GTimer *timer = NULL);
 
 static void	gedit_document_set_readonly	(GeditDocument *doc,
 						 gboolean       readonly);
-
 static void	to_search_region_range 		(GeditDocument *doc,
 						 GtkTextIter   *start, 
 						 GtkTextIter   *end);
@@ -91,7 +90,6 @@ static void	delete_range_cb 		(GeditDocument *doc,
 			     
 struct _GeditDocumentPrivate
 {
-	gint	     auto_save : 1;
 	gint	     readonly : 1;
 	gint	     last_save_was_manually : 1; 	
 	gint	     language_set_by_user : 1;
@@ -108,9 +106,6 @@ struct _GeditDocumentPrivate
 
 	gchar	    *mime_type;
 
-	gint	     auto_save_interval;
-	guint	     auto_save_timeout;
-
 	time_t       mtime;
 
 	GTimeVal     time_of_last_save_or_load;
@@ -214,9 +209,6 @@ gedit_document_finalize (GObject *object)
 	
 	gedit_debug (DEBUG_DOCUMENT);
 
-	if (doc->priv->auto_save_timeout > 0)
-		g_source_remove (doc->priv->auto_save_timeout);
-
 	if (doc->priv->untitled_number > 0)
 	{
 		g_return_if_fail (doc->priv->uri == NULL);
@@ -639,13 +631,6 @@ gedit_document_init (GeditDocument *doc)
 	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (doc), 
 					      gedit_prefs_manager_get_bracket_matching ());
 
-	doc->priv->auto_save = gedit_prefs_manager_get_auto_save ();
-	doc->priv->auto_save = (doc->priv->auto_save != FALSE);
-
-	doc->priv->auto_save_interval = gedit_prefs_manager_get_auto_save_interval ();
-	if (doc->priv->auto_save_interval <= 0)
-		doc->priv->auto_save_interval = GPM_DEFAULT_AUTO_SAVE_INTERVAL;
-
 	gedit_document_set_enable_search_highlighting (doc,
 						       gedit_prefs_manager_get_enable_search_highlighting ());
 
@@ -690,8 +675,9 @@ set_uri (GeditDocument *doc,
 		if (doc->priv->vfs_uri != NULL)
 			gnome_vfs_uri_unref (doc->priv->vfs_uri);
 
+		/* Note: vfs_uri may be NULL for some valid but
+		 * unsupported uris */
 		doc->priv->vfs_uri = gnome_vfs_uri_new (uri);
-		g_return_if_fail (doc->priv->vfs_uri != NULL);
 
 		if (doc->priv->untitled_number > 0)
 		{
@@ -700,8 +686,6 @@ set_uri (GeditDocument *doc,
 		}
 	}
 
-	g_return_if_fail (doc->priv->vfs_uri != NULL);
-
 	g_free (doc->priv->mime_type);
 	if (mime_type != NULL)
 	{
@@ -709,10 +693,11 @@ set_uri (GeditDocument *doc,
 	}
 	else
 	{
-		gchar *base_name;
+		gchar *base_name = NULL;
 
 		/* Guess the mime type from file extension or fallback to "text/plain" */
-		base_name = gnome_vfs_uri_extract_short_path_name (doc->priv->vfs_uri);
+		if (doc->priv->vfs_uri != NULL)
+			base_name = gnome_vfs_uri_extract_short_path_name (doc->priv->vfs_uri);
 		if (base_name != NULL)
 		{
 			const gchar *detected_mime;
@@ -723,13 +708,13 @@ set_uri (GeditDocument *doc,
 				detected_mime = "text/plain";
 
 			doc->priv->mime_type = g_strdup (detected_mime);
+
+			g_free (base_name);
 		}
 		else
 		{
 			doc->priv->mime_type = g_strdup ("text/plain");
 		}
-
-		g_free (base_name);
 	}
 
 	if (!doc->priv->language_set_by_user)
@@ -800,6 +785,7 @@ get_uri_shortname_for_display (GnomeVFSURI *uri)
 	gboolean  validated;
 
 	validated = FALSE;
+
 	name = gnome_vfs_uri_extract_short_name (uri);
 	
 	if (name == NULL)
@@ -868,6 +854,8 @@ gedit_document_get_short_name_for_display (GeditDocument *doc)
 	if (doc->priv->uri == NULL)
 		return g_strdup_printf (_("Unsaved Document %d"),
 					doc->priv->untitled_number);	      
+	else if (doc->priv->vfs_uri == NULL)
+		return g_strdup (doc->priv->uri);
 	else
 		return get_uri_shortname_for_display (doc->priv->vfs_uri);
 }
@@ -891,28 +879,6 @@ set_readonly (GeditDocument *doc,
 	
 	readonly = (readonly != FALSE);
 
-	if (readonly) 
-	{
-		if (doc->priv->auto_save_timeout > 0)
-		{
-			g_source_remove (doc->priv->auto_save_timeout);
-			doc->priv->auto_save_timeout = 0;
-		}
-	}
-	else
-	{
-		if (doc->priv->auto_save &&
-		    (doc->priv->auto_save_timeout <= 0) && 
-                    !gedit_document_is_untitled (doc))
-		{
-/*			doc->priv->auto_save_timeout = g_timeout_add
-				 (doc->priv->auto_save_interval * 1000 * 60,
-		 		 (GSourceFunc)gedit_document_auto_save,
-		  		 doc);
-*/
-		}
-	}
-
 	if (doc->priv->readonly == readonly) 
 		return;
 
@@ -1061,18 +1027,18 @@ document_loader_loading (GeditDocumentLoader *loader,
 	}
 }
 
-gboolean
+void
 gedit_document_load (GeditDocument       *doc,
 		     const gchar         *uri,
 		     const GeditEncoding *encoding,
 		     gint                 line_pos,
 		     gboolean             create)
 {
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
-	g_return_val_if_fail (uri != NULL, FALSE);
-	g_return_val_if_fail (gedit_utils_is_valid_uri (uri), FALSE);
+	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
+	g_return_if_fail (uri != NULL);
+	g_return_if_fail (gedit_utils_is_valid_uri (uri));
 
-	g_return_val_if_fail (doc->priv->loader == NULL, FALSE);
+	g_return_if_fail (doc->priv->loader == NULL);
 
 	/* create a loader. It will be destroyed when loading is completed */
 	doc->priv->loader = gedit_document_loader_new (doc);
@@ -1088,9 +1054,9 @@ gedit_document_load (GeditDocument       *doc,
 
 	set_uri (doc, uri, NULL);
 
-	return gedit_document_loader_load (doc->priv->loader,
-					   uri,
-					   encoding);
+	gedit_document_loader_load (doc->priv->loader,
+				    uri,
+				    encoding);
 }
 
 gboolean
@@ -1110,9 +1076,7 @@ document_saver_saving (GeditDocumentSaver *saver,
 		       const GError       *error,
 		       GeditDocument      *doc)
 {
-	/* FIXME */
-	if (error)
-		g_print ("error saving: %s\n", error->message);
+	gedit_debug (DEBUG_DOCUMENT);
 
 	if (completed)
 	{
@@ -1133,9 +1097,9 @@ document_saver_saving (GeditDocumentSaver *saver,
 
 			gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (doc),
 						      FALSE);
-			
+
 			set_uri (doc, uri, mime_type);
-			
+
 			set_encoding (doc, 
 				      doc->priv->requested_encoding, 
 				      TRUE);
@@ -1257,12 +1221,13 @@ gedit_document_is_untitled (GeditDocument *doc)
 	return (doc->priv->uri == NULL);
 }
 
+
 gboolean
 gedit_document_get_deleted (GeditDocument *doc)
 {
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
 
-	if (doc->priv->uri == NULL)
+	if (doc->priv->uri == NULL || doc->priv->vfs_uri == NULL)
 		return FALSE;
 		
 	return !gnome_vfs_uri_exists (doc->priv->vfs_uri);
@@ -1295,13 +1260,19 @@ gedit_document_goto_line (GeditDocument *doc,
 
 	line_count = gtk_text_buffer_get_line_count (GTK_TEXT_BUFFER (doc));
 
-	if (line > line_count)
+	if (line >= line_count)
 	{
 		ret = FALSE;
-		line = line_count;
+		gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (doc),
+					      &iter);
+	}
+	else
+	{
+		gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (doc),
+						  &iter,
+						  line);
 	}
 
-	gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (doc), &iter, line);
 	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
 
 	return ret;
@@ -1572,8 +1543,10 @@ gedit_document_replace_all (GeditDocument       *doc,
 	gchar *search_text;
 	gchar *replace_text;
 	gint replace_text_len;
-	GtkTextBuffer *buffer;	
-	
+	GtkTextBuffer *buffer;
+	gboolean check_brackets;
+	gboolean search_highliting;
+
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
 	g_return_val_if_fail (replace != NULL, 0);
 	g_return_val_if_fail ((find != NULL) || (doc->priv->search_text != NULL), 0);
@@ -1584,18 +1557,18 @@ gedit_document_replace_all (GeditDocument       *doc,
 		search_text = g_strdup (doc->priv->search_text);
 	else
 		search_text = gedit_utils_unescape_search_text (find);
-		
+
 	replace_text = gedit_utils_unescape_search_text (replace);
-		
+
 	gtk_text_buffer_get_start_iter (buffer, &iter);
-		
+
 	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (flags))
 	{
 		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
 	}
-	
+
 	replace_text_len = strlen (replace_text);
 
 	/* disable cursor_moved emission until the end of the
@@ -1604,8 +1577,16 @@ gedit_document_replace_all (GeditDocument       *doc,
 	 */
 	doc->priv->stop_cursor_moved_emission = TRUE;
 
+	/* also avoid spending time matching brackets */
+	check_brackets = gtk_source_buffer_get_check_brackets (GTK_SOURCE_BUFFER (buffer));
+	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (buffer), FALSE);
+
+	/* and do search highliting later */
+	search_highliting = gedit_document_get_enable_search_highlighting (doc);
+	gedit_document_set_enable_search_highlighting (doc, FALSE);
+
 	gtk_text_buffer_begin_user_action (buffer);
-	
+
 	do
 	{
 		found = gtk_source_iter_forward_search (&iter,
@@ -1614,29 +1595,28 @@ gedit_document_replace_all (GeditDocument       *doc,
                         	                	&m_start, 
                         	                	&m_end,
                                 	               	NULL);
-								      	               	
+
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (flags))
 		{
 			gboolean word;
-						
+
 			word = gtk_text_iter_starts_word (&m_start) && 
 			       gtk_text_iter_ends_word (&m_end);
-				
+
 			if (!word)
 			{
 				iter = m_end;
 				continue;
 			}
 		}
-		
+
 		if (found)
 		{
 			++cont;
-			
+
 			gtk_text_buffer_delete (buffer, 
 						&m_start,
 						&m_end);
-		
 			gtk_text_buffer_insert (buffer,
 						&m_start,
 						replace_text,
@@ -1655,13 +1635,17 @@ gedit_document_replace_all (GeditDocument       *doc,
 	doc->priv->stop_cursor_moved_emission = FALSE;
 	emit_cursor_moved (doc);
 
+	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (buffer),
+					      check_brackets);
+	gedit_document_set_enable_search_highlighting (doc, search_highliting);
+
 	g_free (search_text);
-	g_free (replace_text);	
+	g_free (replace_text);
 
 	return cont;
-}			    
+}
 
-void 
+void
 gedit_document_set_language (GeditDocument     *doc, 
 			     GtkSourceLanguage *lang)
 {
@@ -1686,35 +1670,6 @@ gedit_document_get_encoding (GeditDocument *doc)
 	return doc->priv->encoding;
 }
 
-void
-gedit_document_set_auto_save_enabled (GeditDocument *doc, 
-				      gboolean       enable)
-{
-	gedit_debug (DEBUG_DOCUMENT);
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-
-	enable = (enable != FALSE);
-	
-	// TODO
-	
-	return;
-}
-
-void
-gedit_document_set_auto_save_interval (GeditDocument *doc, 
-				       gint           interval)
-{
-	gedit_debug (DEBUG_DOCUMENT);
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-	g_return_if_fail (interval > 0);
-
-	// TODO
-
-	return;
-}
-
 glong
 _gedit_document_get_seconds_since_last_save_or_load (GeditDocument *doc)
 {
