@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c,v 1.17 2006/02/12 11:57:51 pborelli Exp $
+ * $Id: gedit-window.c,v 1.19 2006/02/25 01:07:10 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -560,6 +560,11 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 					      "SearchFindPrevious");
 	gtk_action_set_sensitive (action, state_normal && b);
 
+	action = gtk_action_group_get_action (window->priv->action_group,
+					      "SearchClearHighlight");
+	gtk_action_set_sensitive (action, state_normal && b);
+
+
 	action = gtk_action_group_get_action (window->priv->action_group,
 					      "SearchGoToLine");
 	gtk_action_set_sensitive (action, state_normal);
@@ -1973,6 +1978,10 @@ can_search_again (GeditDocument *doc,
 	action = gtk_action_group_get_action (window->priv->action_group,
 					      "SearchFindPrevious");
 	gtk_action_set_sensitive (action, sensitive);
+
+	action = gtk_action_group_get_action (window->priv->action_group,
+					      "SearchClearHighlight");
+	gtk_action_set_sensitive (action, sensitive);
 }
 
 static void
@@ -2570,7 +2579,7 @@ bottom_panel_visibility_changed (GeditPanel  *bottom_panel,
 		gedit_prefs_manager_set_bottom_panel_visible (visible);
 
 	action = gtk_action_group_get_action (window->priv->action_group,
-					      "ViewBottomPanel");
+					      "ViewBottomPane");
 
 	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)) != visible)
 		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), visible);
@@ -2601,7 +2610,7 @@ bottom_panel_item_removed (GeditPanel  *panel,
 		gtk_widget_hide (GTK_WIDGET (panel));
 
 		action = gtk_action_group_get_action (window->priv->action_group,
-						      "ViewBottomPanel");
+						      "ViewBottomPane");
 		gtk_action_set_sensitive (action, FALSE);
 	}
 }
@@ -2619,7 +2628,7 @@ bottom_panel_item_added (GeditPanel  *panel,
 		gboolean show;
 
 		action = gtk_action_group_get_action (window->priv->action_group,
-						      "ViewBottomPanel");
+						      "ViewBottomPane");
 		gtk_action_set_sensitive (action, TRUE);
 
 		show = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
@@ -2677,7 +2686,7 @@ init_panels_visibility (GeditWindow *window)
 	{
 		GtkAction *action;
 		action = gtk_action_group_get_action (window->priv->action_group,
-						      "ViewBottomPanel");
+						      "ViewBottomPane");
 		gtk_action_set_sensitive (action, FALSE);
 	}
 
